Struct

BirbAttrMention

since: 0.8

Description [src]

struct BirbAttrMention {
  PangoAttribute attr;
  BirbMention type;
  char* id;
  char* color;
}

Holds all data for a mention as a PangoAttribute.

This should be added to a PangoAttrList when creating or reading messages to attach the mention data to the text it belongs to. The literal text is what will be displayed, but this data can be used by everything else.

Structure members
attr

The common portion of the attribute.

type

The type of mention.

id

The id of who/what was mentioned.

color

An optional RGB hex color code.

Available since: 0.8

Functions

birb_attr_mention_new

Creates a new PangoAttribute to represent a “mention”.

since: 0.8