Struct
BirbAttrLink
since: 0.10
Description [src]
struct BirbAttrLink {
PangoAttribute attr;
char* href;
char* title;
}
Holds all data for a link as a PangoAttribute.
This should be added to a PangoAttrList when creating or reading
messages to mark text as hyperlinked. The literal text is what will be
displayed, but this data can be used by everything else.
Structure members
attrThe common portion of the attribute.
hrefThe URI.
titleAn optional title.
Available since: 0.10