Struct
BirbAttrMention
since: 0.8
Description [src]
struct BirbAttrMention {
PangoAttribute attr;
BirbMention type;
char* id;
char* color;
}
Holds all data for a mention as a PangoAttribute.
This should be added to a PangoAttrList when creating or reading
messages to attach the mention data to the text it belongs to. The literal
text is what will be displayed, but this data can be used by everything else.
Structure members
attrThe common portion of the attribute.
typeThe type of mention.
idThe id of who/what was mentioned.
colorAn optional RGB hex color code.
Available since: 0.8